@@ -193,7 +193,7 @@ class MathTable:
         italicscorrections = []
         for i in range(cnt):
             italicscorrections.append(read_valuerecord(self.fontfile))
-        italicscoverage = Coverage(self.ofst+ofst+italics+covofst, self.fontfile)
+        italicscoverage = Coverage(self.ofst+ofst+italics+covofst, self.fontfile, nulltable=(italics==0))
 
         # Top Accent Attachment Table
         self.fontfile.seek(self.ofst + ofst + topaccent)
@@ -202,13 +202,16 @@ class MathTable:
         accents = []
         for i in range(cnt):
             accents.append(read_valuerecord(self.fontfile))
-        accentcoverage = Coverage(self.ofst+ofst+topaccent+covofst, self.fontfile)
+        accentcoverage = Coverage(self.ofst+ofst+topaccent+covofst, self.fontfile, nulltable=(topaccent==0))
 
         # Extended Shape Coverage
-        extshapes = Coverage(self.ofst+ofst+extendshape, self.fontfile)
+        extshapes = Coverage(self.ofst+ofst+extendshape, self.fontfile, nulltable=(extendshape==0))
 
         # Kern Info
-        kerninfo = MathKernInfoTable(self.ofst+ofst+kernofst, self.fontfile)
+        if kernofst:
+            kerninfo = MathKernInfoTable(self.ofst+ofst+kernofst, self.fontfile, nulltable=(kernofst==0))
+        else:
+            kerninfo = None
 
         self.italicsCorrection = MathSubTable(italicscorrections, italicscoverage)
         self.topAccentAttachment = MathSubTable(accents, accentcoverage)
@@ -249,6 +252,10 @@ class MathTable:
                 kern: Kerning shift to apply in x direction
                 shift: Upward shift of superscript with respect to baseline
         '''
+        if self.kernInfo is None:
+            return 0, max(self.consts.superscriptShiftUp,
+                          self.consts.superscriptBottomMin)
+
         g1 = self.kernInfo.glyph(glyph1.index)
         g2 = self.kernInfo.glyph(glyph2.index)
 
@@ -281,6 +288,10 @@ class MathTable:
                 kern: Kerning shift to apply in x direction
                 shift: Downward shift of subscript with respect to baseline
         '''
+        if self.kernInfo is None:
+            return 0, max(self.consts.subscriptTopMax,
+                           self.consts.subscriptShiftDown)
+
         g1 = self.kernInfo.glyph(glyph1.index)
         g2 = self.kernInfo.glyph(glyph2.index)
 
@@ -522,25 +533,32 @@ class MathKernInfoTable:
             ofst: Byte offset into font file
             fontfile: Font File
     '''
-    def __init__(self, ofst: int, fontfile: FontReader):
-        fontfile.seek(ofst)
-        covofst = fontfile.readuint16()
-        cnt = fontfile.readuint16()
-        self.kerninfo = []
-        for i in range(cnt):
-            tr = fontfile.readuint16()
-            tl = fontfile.readuint16()
-            br = fontfile.readuint16()
-            bl = fontfile.readuint16()
-            self.kerninfo.append(MathKernInfoRecord(
-                MathKernTable(tr+ofst, fontfile) if tr else ZeroKern(),
-                MathKernTable(tl+ofst, fontfile) if tl else ZeroKern(),
-                MathKernTable(br+ofst, fontfile) if br else ZeroKern(),
-                MathKernTable(bl+ofst, fontfile) if bl else ZeroKern()))
-        self.coverage = Coverage(ofst+covofst, fontfile)
+    def __init__(self, ofst: int, fontfile: FontReader, nulltable: bool = False):
+        if nulltable:
+            self.kerninfo = None
+            self.coverage = None
+        else:
+            fontfile.seek(ofst)
+            covofst = fontfile.readuint16()
+            cnt = fontfile.readuint16()
+            self.kerninfo = []
+            for i in range(cnt):
+                tr = fontfile.readuint16()
+                tl = fontfile.readuint16()
+                br = fontfile.readuint16()
+                bl = fontfile.readuint16()
+                self.kerninfo.append(MathKernInfoRecord(
+                    MathKernTable(tr+ofst, fontfile) if tr else ZeroKern(),
+                    MathKernTable(tl+ofst, fontfile) if tl else ZeroKern(),
+                    MathKernTable(br+ofst, fontfile) if br else ZeroKern(),
+                    MathKernTable(bl+ofst, fontfile) if bl else ZeroKern()))
+            self.coverage = Coverage(ofst+covofst, fontfile)
 
     def glyph(self, glyphid: int) -> Optional[MathKernInfoRecord]:
         ''' Get kerning info record for this glyph '''
+        if self.coverage is None:
+            return None
+
         idx = self.coverage.covidx(glyphid)
         if idx is not None:
             return self.kerninfo[idx]
